==> haskell-mono-traversable-instances-0.1.1.0-187-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-ApxL2zyyqm9Oqjybp70RK
key:                  mono-traversable-instances-0.1.1.0-ApxL2zyyqm9Oqjybp70RK
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  88de65e8382735f8f198fd937ff5afcd
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-ApxL2zyyqm9Oqjybp70RK
depends:
    base-4.15.1.0 comonad-5.0.8-1zgluuiDxbA1HxKV8ftkIY
    containers-0.6.4.1 dlist-1.0-JalAZsGq1LOCqqdFHHEpoL
    dlist-instances-0.1.1.1-FWoepFV5DZgKPsqgDH9foT
    mono-traversable-1.0.15.3-Ai7DTojHfQp3FhGjUsBhnE
    semigroupoids-5.3.7-8Z8Rca56BuE8mvKgtu1SkI transformers-0.5.6.2
    vector-instances-3.4.2-8OGeKvkl4lXH2fFDKwXNWM

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-instances-0.1.1.0-210-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-7PxpgPTEo7JEk16s4Bpp3
key:                  mono-traversable-instances-0.1.1.0-7PxpgPTEo7JEk16s4Bpp3
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  657df3f5d7dac432222374c88b550698
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mono-traversable-instances
hs-libraries:         HSmono-traversable-instances-0.1.1.0-7PxpgPTEo7JEk16s4Bpp3
depends:
    base-4.15.1.0 comonad-5.0.8-J2wjUEuFB6OFtEoN8dpdww
    containers-0.6.4.1 dlist-1.0-Ge5E4TM9DngAWe8aSUgFvB
    dlist-instances-0.1.1.1-LrKoaMRhclrI8DC005b1Ko
    mono-traversable-1.0.15.3-B5vnE8CJ4Yi8YLVzLJKJaE
    semigroupoids-5.3.7-GoTx94maRcpLxMeVXfADal transformers-0.5.6.2
    vector-instances-3.4.2-GfloDcXk8y1GYZTGwV3e6

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
